rm(list=ls(all=TRUE))

# pecify location to read files
setwd("C:/COVID_Ethiopia")

library(readstata13)
library(haven)
library(ggplot2)
library(rmarkdown)
library(readxl)
library(magrittr)
library(summarytools)
library(formattable)
library(ggplot2)
library(zoo)
library(FSA)
library(reshape2)
library(plyr)
library(dplyr)
library(reshape2)
library(lubridate)
library(ggpubr)
library(arsenal)
library(stringi)
library(stringr)
library(tidyr)
library(foreign)
library(stats4)
library(glmmTMB)
library(bbmle)
library(countreg)
library(cowplot) 
library(lme4) 
library(sjPlot) 
library(sjmisc) 
library(effects)
library(sjstats) 
library(tidyquant)
library(binom)
library(geepack)
library(gee)
library(BAS)
library(BMS)
library(DTComPair)
library(ggpmisc)
library(pscl)
library(hurdlr)
library(PupillometryR)
library(broom.mixed)
library(emmeans)
library(epitools)
library(patchwork)
library(svglite)
library(visdat)
library(JointAI)
library(pbkrtest)
library(openxlsx)
library(geepack)
library(partykit)
library(rmarkdown)
library(GLMMadaptive)
library(brms)
library(bayesplot)
library(ggplot2)
library(rstanarm) 

incidence_num<-read.xlsx("Incidence Summary_Ethiopia.xlsx",colNames = TRUE)

colnames(incidence_num)<- c("Group1","Group2","Positives","Personweeks")

incidence_num<- incidence_num[which(incidence_num$Group2 %in% c("Health Care Workers","Community - Combined")),]

incidence_num$Group<- paste(incidence_num$Group1,"_",incidence_num$Group2)


fit1 <- brm(
  Positives|trials(Personweeks)  ~ Group, data =incidence_num, 
  prior = c(prior(normal(0, 10), class = Intercept),
            prior(normal(0, 10), class = b)),
  chains = 3,warmup = 5000, 
  iter = 10000,
  control = list(adapt_delta = 0.95),family = binomial,seed=1234
)
mcmc_plot(fit1, 
          type = "trace")
d<-cbind(incidence_num,fitted(fit1))
d$prev_est<- d$Estimate/d$Personweeks
d$prev_2.5<- d$Q2.5/d$Personweeks
d$prev_97.5.5<- d$Q97.5/d$Personweeks


incidence_num$logPW<- log(incidence_num$Personweeks)
fit2 <- brm(data = incidence_num, family = poisson,
            Positives ~ offset(logPW) + Group,
            prior = c(prior(normal(0, 10), class = Intercept),
                      prior(normal(0, 10), class = b)),
            chains = 3,warmup = 5000, 
            iter = 10000,thin = 10,
            control = list(adapt_delta = 0.95),
            seed = 1234)

f<-cbind(incidence_num,fitted(fit2))
f$prev_est<- f$Estimate /f$Personweeks
f$prev_2.5<- f$Q2.5 /f$Personweeks
f$prev_97.5.5<- f$Q97.5/f$Personweeks

d$dist<- "Binomial"
f$dist<- "Poisson"

t1<- rbind(d[c(1,2,3,4,10,11,12,13,14)], f[c(1,2,3,4,11,12,13,14,15)])


t1$Group1<- factor(t1$Group1, labels = c("Addis Ababa","Jimma"))
t1$Group2<- factor(t1$Group2, levels = c("Health Care Workers","Community - Combined"),
                   labels = c("Health Care Workers","Community"))
t1$labels<- paste0(t1$Group2,"\n(",t1$Personweeks," person weeks)")
ggplot(t1, aes(y=round(100*prev_est,2),x=labels))+
  geom_point(aes(colour=dist),position = position_dodge(width = 0.9))+ 
  geom_errorbar(aes(ymin =100*prev_2.5, ymax =100*prev_97.5.5, colour=dist), position = position_dodge(width = 0.9),
                width = 0.5)+facet_grid(Group1~.,scales = "free")+
  
  ylab("Incidence\n(per 100 person weeks)")+ xlab(NULL)+theme_classic()+
  labs(colour="Outcome distribution")+ scale_y_continuous(breaks = c(0,0.5,1.0,1.5,2.0,2.5,3.0,3.5,
                                                                     4.0,4.5,5.0,5.5,6.0,6.5,7.0,7.5))+
 coord_flip()+ theme_classic()+ theme(legend.position="bottom")+
  scale_colour_manual(values=c("#1f77b4", "#ff7f0e"))

ggsave("Incidence_Eth.jpeg",height=7, width = 7, units="in",dpi=720)
write.csv(t1,"incidence_eth.csv")

# Ethiopia Prevalence

eth_prev<- read.csv("Eth_prev.csv",header = T)
eth_prev$Visit<- paste("V_",eth_prev$Round)
eth_prev$Visit<- factor(eth_prev$Visit)


fit1 <- brm(
  n|trials(N)  ~ Population*Visit, data =eth_prev, 
  prior = c(prior(normal(0, 10), class = Intercept),
            prior(normal(0, 10), class = b)),
  chains = 3,warmup = 5000, 
  iter = 10000,
  control = list(adapt_delta = 0.95),family = binomial,seed=1234
)
mcmc_plot(fit1, 
          type = "trace")
d<-cbind(eth_prev,fitted(fit1))
d$prev_est<- d$Estimate/d$N
d$prev_2.5<- d$Q2.5/d$N
d$prev_97.5<- d$Q97.5/d$N

eth_prev$logN<- log(eth_prev$N)
fit2 <- brm(data = eth_prev, family = poisson,
           n ~ offset(logN) + Population*Visit,
            prior = c(prior(normal(0, 10), class = Intercept),
                      prior(normal(0, 10), class = b)),
            chains = 3,warmup = 5000, 
            iter = 10000,thin = 10,
            control = list(adapt_delta = 0.95),
            seed = 1234)

f<-cbind(eth_prev,fitted(fit2))
f$prev_est<- f$Estimate /f$N
f$prev_2.5<- f$Q2.5 /f$N
f$prev_97.5<- f$Q97.5/f$N


write.csv(d, "updated_prevalence_binom.csv")
write.csv(f, "updated_prevalence_pois.csv")
